==> adx-center-api-0.0.12-sources.jar: cn/com/duiba/tuia/adx/center/api/dto/commodity/ActivityCommerceDto.java <==
package cn.com.duiba.tuia.adx.center.api.dto.commodity;

import java.io.Serializable;
import java.util.List;

/**
 * 活动【二类电商】商品信息
 * Created by xuefeng on 2020/7/13.
 */
public class ActivityCommerceDto implements Serializable {

    private static final long serialVersionUID = 853719646365234285L;

    private Long id;

    private Long activityId;

    /**
     * 商品组 多个商品可以归属于一个商品组，占用一个位置
     */
    private Long commerceGroup;

    private Long commerceId;

    /**商品类型枚举类 cn.com.duiba.tuia.activity.center.api.bean.enums.commodity.CommerceTypeEnum**/
    private Integer commerceType;

    private CommerceGoodsDto commerceGoodsDto;

    /**关联id**/
    private List<Long> relationIds;

    /**关联跳转地址**/
    private String relationUrl;

    /**按钮文案**/
    private String buttonDesc;

    /**兜底百奇商品id**/
    private Long defaultBqId;

    /**
     * 商品展示类型
     */
    private Boolean showCommerceUrlFlag;

    /**
     * 是否有预算
     */
    private Boolean haveBudgetFlag;

    /**
     * 排序
     **/
    private Integer cOrder;


    public Boolean getShowCommerceUrlFlag() {
        return showCommerceUrlFlag;
    }

    public void setShowCommerceUrlFlag(Boolean showCommerceUrlFlag) {
        this.showCommerceUrlFlag = showCommerceUrlFlag;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getCommerceGroup() {
        return commerceGroup;
    }

    public void setCommerceGroup(Long commerceGroup) {
        this.commerceGroup = commerceGroup;
    }

    public Long getCommerceId() {
        return commerceId;
    }

    public void setCommerceId(Long commerceId) {
        this.commerceId = commerceId;
    }

    public Integer getCommerceType() {
        return commerceType;
    }

    public void setCommerceType(Integer commerceType) {
        this.commerceType = commerceType;
    }

    public CommerceGoodsDto getCommerceGoodsDto() {
        return commerceGoodsDto;
    }

    public void setCommerceGoodsDto(CommerceGoodsDto commerceGoodsDto) {
        this.commerceGoodsDto = commerceGoodsDto;
    }

    public List<Long> getRelationIds() {
        return relationIds;
    }

    public void setRelationIds(List<Long> relationIds) {
        this.relationIds = relationIds;
    }

    public String getRelationUrl() {
        return relationUrl;
    }

    public void setRelationUrl(String relationUrl) {
        this.relationUrl = relationUrl;
    }

    public String getButtonDesc() {
        return buttonDesc;
    }

    public void setButtonDesc(String buttonDesc) {
        this.buttonDesc = buttonDesc;
    }

    public Long getDefaultBqId() {
        return defaultBqId;
    }

    public void setDefaultBqId(Long defaultBqId) {
        this.defaultBqId = defaultBqId;
    }

    public Boolean getHaveBudgetFlag() {
        return haveBudgetFlag;
    }

    public void setHaveBudgetFlag(Boolean haveBudgetFlag) {
        this.haveBudgetFlag = haveBudgetFlag;
    }

    public Integer getcOrder() {
        return cOrder;
    }

    public void setcOrder(Integer cOrder) {
        this.cOrder = cOrder;
    }
}

==> adx-center-api-0.0.15-sources.jar: cn/com/duiba/tuia/adx/center/api/dto/commodity/ActivityCommerceDto.java <==
package cn.com.duiba.tuia.adx.center.api.dto.commodity;

import java.io.Serializable;
import java.util.List;

/**
 * 活动【二类电商】商品信息
 * Created by xuefeng on 2020/7/13.
 */
public class ActivityCommerceDto implements Serializable {

    private static final long serialVersionUID = 853719646365234285L;

    private Long id;

    private Long activityId;

    /**
     * 商品组 多个商品可以归属于一个商品组，占用一个位置
     */
    private Long commerceGroup;

    private Long commerceId;

    /**商品类型枚举类 cn.com.duiba.tuia.adx.center.api.bean.enums.commodity.CommerceTypeEnum**/
    private Integer commerceType;

    private CommerceGoodsDto commerceGoodsDto;

    /**关联id**/
    private List<Long> relationIds;

    /**关联跳转地址**/
    private String relationUrl;

    /**按钮文案**/
    private String buttonDesc;

    /**兜底百奇商品id**/
    private Long defaultBqId;

    /**
     * 商品展示类型
     */
    private Boolean showCommerceUrlFlag;

    /**
     * 是否有预算
     */
    private Boolean haveBudgetFlag;

    /**
     * 排序
     **/
    private Integer cOrder;


    public Boolean getShowCommerceUrlFlag() {
        return showCommerceUrlFlag;
    }

    public void setShowCommerceUrlFlag(Boolean showCommerceUrlFlag) {
        this.showCommerceUrlFlag = showCommerceUrlFlag;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getCommerceGroup() {
        return commerceGroup;
    }

    public void setCommerceGroup(Long commerceGroup) {
        this.commerceGroup = commerceGroup;
    }

    public Long getCommerceId() {
        return commerceId;
    }

    public void setCommerceId(Long commerceId) {
        this.commerceId = commerceId;
    }

    public Integer getCommerceType() {
        return commerceType;
    }

    public void setCommerceType(Integer commerceType) {
        this.commerceType = commerceType;
    }

    public CommerceGoodsDto getCommerceGoodsDto() {
        return commerceGoodsDto;
    }

    public void setCommerceGoodsDto(CommerceGoodsDto commerceGoodsDto) {
        this.commerceGoodsDto = commerceGoodsDto;
    }

    public List<Long> getRelationIds() {
        return relationIds;
    }

    public void setRelationIds(List<Long> relationIds) {
        this.relationIds = relationIds;
    }

    public String getRelationUrl() {
        return relationUrl;
    }

    public void setRelationUrl(String relationUrl) {
        this.relationUrl = relationUrl;
    }

    public String getButtonDesc() {
        return buttonDesc;
    }

    public void setButtonDesc(String buttonDesc) {
        this.buttonDesc = buttonDesc;
    }

    public Long getDefaultBqId() {
        return defaultBqId;
    }

    public void setDefaultBqId(Long defaultBqId) {
        this.defaultBqId = defaultBqId;
    }

    public Boolean getHaveBudgetFlag() {
        return haveBudgetFlag;
    }

    public void setHaveBudgetFlag(Boolean haveBudgetFlag) {
        this.haveBudgetFlag = haveBudgetFlag;
    }

    public Integer getcOrder() {
        return cOrder;
    }

    public void setcOrder(Integer cOrder) {
        this.cOrder = cOrder;
    }
}
